import unittest
from .chatwebhook import ChatWebhook

class ChatWebhookTests(unittest.TestCase):
    def test_init(self):
        """Test the __init__() method."""
        wh = ChatWebhook(key='webhook-key', event='conversation:updates', url='https://my-external-service.com/stride-webhooks')

        wh_descriptor = wh.to_descriptor()
        expected = {'key': 'webhook-key', 'event': 'conversation:updates', 'url': 'https://my-external-service.com/stride-webhooks'}

        self.assertEqual(wh_descriptor, expected)

if __name__ == '__main__':
    unittest.main()



from .module import Module

class ChatConfiguration(Module):
    type = 'chat:configuration'

    def __init__(self, key, page_url=None, page_target=None, externalpage_url=None, state_url=None):
        super().__init__(key)

        targets = [ page_url, page_target, externalpage_url ]

        non_null_targets = [ t for t in targets if t is not None ]

        num_targets = len(non_null_targets)
        if num_targets != 1:
            raise ValueError('Must have exactly 1 target. Received {}'.format(num_targets))

        if page_url is not None:
            self.add_property('page', {'url': page_url})

        if page_target is not None:
            self.add_property('page', {'url': page_target})

        if externalpage_url is not None:
            self.add_property('page', {'url': externalpage_url})

        if state_url is not None:
            self.add_property('state', {'url': state_url})



import unittest
from .condition import BuiltinConditionClause, CompositeConditionClause

class BuiltinConditionClauseTests(unittest.TestCase):
    def test_init_public(self):
        """Create a Builtin Condition Clause to denote a public conversation."""
        bcc = BuiltinConditionClause('conversation_is_public')

        bcc_descriptor = bcc.to_descriptor()
        expected = {'condition': 'conversation_is_public'}

        self.assertEqual(bcc_descriptor, expected)

    def test_init_public(self):
        """Create a Builtin Condition Clause to denote a private conversation."""
        bcc = BuiltinConditionClause('conversation_is_public', invert=True)

        bcc_descriptor = bcc.to_descriptor()
        expected = {'condition': 'conversation_is_public', 'invert': True}

        self.assertEqual(bcc_descriptor, expected)

    def test_init_room(self):
        """Create a Builtin Condition Clause to denote a conversation in a room."""
        bcc = BuiltinConditionClause('conversation_is_room')

        bcc_descriptor = bcc.to_descriptor()
        expected = {'condition': 'conversation_is_room'}

        self.assertEqual(bcc_descriptor, expected)

    def test_init_dm(self):
        """Create a Builtin Condition Clause to denote a direct 1-to-1 conversation."""
        bcc = BuiltinConditionClause('conversation_is_room', invert=True)

        bcc_descriptor = bcc.to_descriptor()
        expected = {'condition': 'conversation_is_room', 'invert': True}

        self.assertEqual(bcc_descriptor, expected)

class CompositeConditionClauseTests(unittest.TestCase):
    def test_private_room(self):
        """Test the private room condition."""
        priv = BuiltinConditionClause('conversation_is_public', invert=True)

        room = BuiltinConditionClause('conversation_is_room')

        priv_room = CompositeConditionClause(type='and', conditions=[room, priv])

        pr_descriptor = priv_room.to_descriptor()
        expected = {'type': 'and', 'conditions': [{'condition': 'conversation_is_room'}, {'invert': True, 'condition': 'conversation_is_public'}]}

        self.assertEqual(pr_descriptor, expected)



import unittest
from .chataction import ChatAction

class ChatActionTests(unittest.TestCase):
    def test_init(self):
        """Test the __init__() method."""
        ca = ChatAction(key='act-key', name='Do Stuff', target='my-target-module')

        ca_descriptor = ca.to_descriptor()
        expected = {'key': 'act-key', 'name': {'value':'Do Stuff'}, 'target': 'my-target-module'}

        self.assertEqual(ca_descriptor, expected)

if __name__ == '__main__':
    unittest.main()



import unittest
from .module import Module

class ModuleTests(unittest.TestCase):
    def test_add_property(self):
        """Test the add_property() method."""
        m = Module('module-key') 
        m.add_property('property_1', 'value_1')

        self.assertIn('property_1', m.properties)
        self.assertEqual(m.properties['property_1'], 'value_1')

    def test_del_property(self):
        """Test the del_property() method."""
        m = Module('module-key')
        m.add_property('property_1', 'value_1')
        m.del_property('property_1')

        self.assertNotIn('property_1', m.properties)

    def test_del_property_nonexistent(self):
        """Test the del_property() method on a non-existent property."""
        m = Module('module-key')
        m.del_property('property_1')

    def test_get_property(self):
        """Test the get_property() method."""
        m = Module('module-key')
        m.add_property('property_1', 'value_1')

        self.assertEqual(m.get_property('property_1'), 'value_1')

    def test_get_property_nonexistent(self):
        """Test the get_property() method on an non-existent property."""
        m = Module('module-key')

        self.assertEqual(m.get_property('property_1'), None)

    def test_to_descriptor(self):
        """Test the to_descriptor() method."""
        m = Module('module-key') 
        m.add_property('property_1', 'value_1')

        m_descriptor = m.to_descriptor()
        expected = {'key': 'module-key', 'property_1': 'value_1'}

        self.assertEqual(m.to_descriptor(), expected)

    def test__descriptor_value(self):
        """Test the _descriptor_value() method."""
        m = Module('module-key')
        m2 = Module('module-key-2')
        m2.add_property('m2-property-1', 'hello.')

        m.add_property('property_str', 'this is a string.')
        m.add_property('property_list', ['this', 'is', 'a', 'list'])
        m.add_property('property_dict', {'key': 'value'})
        m.add_property('property_mod', m2)

        m_descriptor = m.to_descriptor()
        expected = {'key': 'module-key', 'property_str': 'this is a string.', 'property_list': ['this', 'is', 'a', 'list'], 'property_dict':{'key': 'value'}, 'property_mod': {'key':'module-key-2','m2-property-1':'hello.'}}

        self.assertEqual(m.to_descriptor(), expected)

    def test_type(self):
        m = Module('module-key')
        self.assertEqual(m.type, None)

if __name__ == '__main__':
    unittest.main()



from .module import Module

class ChatGlance(Module):
    type = 'chat:glance'

    def __init__(self, key, name, icon_1x, icon_2x, i18n=None, target=None, query_url=None, weight=None, conditions=None):
        super().__init__(key)
        name_dict = { 'value': name }
        if i18n is not None:
            name_dict['i18n'] = i18n
        self.add_property('name', name_dict)

        icon_dict = { 'url': icon_1x, 'url@2x': icon_2x }
        self.add_property('icon', icon_dict)

        if query_url is not None:
            self.add_property('queryUrl', query_url)
        
        if target is not None:
            self.add_property('target', target)
        
        if weight is not None:
            self.add_property('weight', weight)
        
        if conditions is not None:
            self.add_property('conditions', conditions)



from setuptools import setup

setup(
  name = 'Flask-Stride',
  packages = ['flask_stride'],
  version = '0.2.17',
  description = 'Flask adapter client for pystride',
  author = 'Dave Chevell',
  author_email = 'dchevell@atlassian.com',
  url = 'https://bitbucket.org/dchevell/flask-stride',
  keywords = ['atlassian', 'stride', 'flask'],
  classifiers = [],
  license = 'MIT',
  install_requires = ['pystride', 'Flask']
)



from .module import Module
from .condition import BuiltinConditionClause, CompositeConditionClause

class ChatAction(Module):

    def __init__(self, key, name, target, weight=None, conditions=None):
        super().__init__(key)
        self.add_property('name', {'value': name})
        self.add_property('target', target)
        if weight is not None:
            self.add_property('weight', weight)
        if conditions is not None:
            self.add_property('conditions', conditions)



from .module import Module

class ChatBotMessage(Module):
    type = 'chat:bot:messages'

    def __init__(self, key, pattern, path):
        super().__init__(key)
        self.add_property('pattern', pattern)
        self.add_property('url', path)
